changeset 56980:1c1ca003ded1

(buffer-auto-save-file-format): Make it permanent local.
author Luc Teirlinck <teirllm@auburn.edu>
date Wed, 08 Sep 2004 02:44:32 +0000
parents f0f48b9999fa
children 54f19dd158e9
files lisp/format.el
diffstat 1 files changed, 2 insertions(+), 1 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/format.el	Wed Sep 08 02:41:53 2004 +0000
+++ b/lisp/format.el	Wed Sep 08 02:44:32 2004 +0000
@@ -37,7 +37,7 @@
 ;; change this variable, or use `format-write-file'.
 ;;
 ;; Auto-save files are normally created in the same format as the visited
 ;; file, but the variable `auto-save-file-format' can be set to a
 ;; particularly fast or otherwise preferred format to be used for
 ;; auto-saving (or nil to do no encoding on auto-save files, but then you
 ;; risk losing any text-properties in the buffer).
@@ -62,6 +62,7 @@
 ;;; Code:
 
 (put 'buffer-file-format 'permanent-local t)
+(put 'buffer-auto-save-file-format 'permanent-local t)
 
 (defvar format-alist
   '((text/enriched "Extended MIME text/enriched format."
@@ -37,7 +37,7 @@
 ;;
 ;; Auto-save files are normally created in the same format as the visited
-;; file, but the variable `auto-save-file-format' can be set to a
+;; file, but the variable `buffer-auto-save-file-format' can be set to a
 ;; particularly fast or otherwise preferred format to be used for
 ;; auto-saving (or nil to do no encoding on auto-save files, but then you